summaryrefslogtreecommitdiffstats
path: root/src/gui/editors/matrix/MatrixView.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/gui/editors/matrix/MatrixView.h')
-rw-r--r--src/gui/editors/matrix/MatrixView.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/gui/editors/matrix/MatrixView.h b/src/gui/editors/matrix/MatrixView.h
index cba9ced..9709c50 100644
--- a/src/gui/editors/matrix/MatrixView.h
+++ b/src/gui/editors/matrix/MatrixView.h
@@ -78,7 +78,7 @@ class LevelInfo;
*/
class MatrixView : public EditView
{
- Q_OBJECT
+ TQ_OBJECT
friend class MatrixSelector;
@@ -666,12 +666,12 @@ protected:
};
// Commented this out - was a MatrixView inner class, but we get a warning
// that Q_OBJECT can't be used in an inner class - gl
//
// class NoteSender : public TQObject
// {
-// Q_OBJECT
+// TQ_OBJECT
//
// public:
@@ -666,12 +666,12 @@ protected:
};
// Commented this out - was a MatrixView inner class, but we get a warning
-// that Q_OBJECT can't be used in an inner class - gl
+// that TQ_OBJECT can't be used in an inner class - gl
//
// class NoteSender : public TQObject